powered by
"sadObj"
a class for design-based estimation only
data
See "'>saeObj".
"'>saeObj"
f
cluster
include
Class "'>savObj", directly.
"'>savObj"
Objects can be created by calls of the form new("sadObj", ...) or via the constructor function "?maSAE::saObj".
new("sadObj", ...)
"?maSAE::saObj"
predict
See "'>saeObj". The fixed effects part of f has to be NULL: design-based estimation knows no fixed effects.
"'>saeObj" "?maSAE::saObj"
# NOT RUN { showClass("sadObj") # }
Run the code above in your browser using DataLab