Class for small area estimation, the one you're probably looking for.
smallAreaMeansAn optional "data.frame"
giving the true means of fixed effects for the small areas.
Must have a column with the random effect defining the small areas in
slot
data.
s1An optional "character" string giving the name of a
variable in slot data indicating that an observation (a row in
slot
data) belongs to subset 1.
s2An optional "character" string giving the name of a
variable in slot data indicating that an observation (a row in
slot
data) belongs to subset 2.
dataObject of class "data.frame" to use for prediction,
typically
consisting of a predictand and one or more predictors (zero or more fixed
effects and one random effect defining the small areas).
See Details for optional clustering variable and/or inclusion
indicator.
fObject of class "formula" a linear mixed effects model
formula.
clusterAn optional "character" string giving the name of
the
clustering variable in slot data.
includeAn optional "character" string giving the name of
the
inclusion indicator in slot data.
auxiliaryWeightsAn optional "character" string giving
the name of the
auxiliary weights in slot data. You will need it, if your
auxiliary
data does not have full spatial support for each observation (for example
when a shapefile does not completely cover all gird cells used to compute
auxiliary data on).
See
vignette("forestinventory_vignette", package = "forestinventory")
for details.
Objects can be created by calls of the form
new("saeObj", ...) or via the constructor function
"?maSAE::saObj" (recommended).
cluster optionally gives the name of a variable in slot data
from which the cluster information for clustered sample designs is to be
read.
See Manadallaz 2013, p. 445 for Details.
include optionally gives the name of a variable in slot data
from which the inclusion indicator for cluster points is to be read.
See Manadallaz 2013, p. 445 for Details on \(I_f\).
Also see the Details for predict.
Mandallaz, D. 2013 Design-based properties of some small-area estimators in forest inventory with two-phase sampling. Canadian Journal of Forest Research 43(5), pp. 441--449. 10.1139/cjfr-2012-0381.
"?stats::formula",
"class?maSAE::saObj",
"class?maSAE::savObj",
"?maSAE::saObj" and
"?maSAE::predict"
Other classes:
characterOrNULL-class,
sadObj-class,
savObj-class
# NOT RUN {
showClass("saeObj")
# }
Run the code above in your browser using DataLab